@@ -18,28 +18,47 @@ read.gson <- function(file) {
   x <- jsonlite::fromJSON(file)
   gsid2gene <- stack(x$gsid2gene)
   gsid2gene <- setNames(gsid2gene[, c(2,1)], c("gsid", "gene"))
-  
   #idx <- which(vapply(x, length, numeric(1)) == 0)
   #for (i in idx) {
   #  x[[i]] <- NULL
   #}
-  
+
+
   gsid2name <- x$gsid2name
   if (!is.null(gsid2name)) {
     gsid2name <- as.data.frame(gsid2name)
   }
   
   gene2name <- x$gene2name
+  if (length(gene2name) == 0) {
+    gene2name <- NULL
+  }
   if (!is.null(gene2name)) {
     gene2name <- as.data.frame(gene2name)
   }
+
+  get_value <- function(value, x) {
+    result <- x[[value]]
+    if (length(result > 0)) {
+      result <- as.character(result)
+    } else {
+      result <- NULL
+    }
+    result
+  }
+
+  gsname <- get_value("gsname", x)
+  version <- get_value("version", x)
+  accessed_date <- get_value("accessed_date", x)
+  keytype <- get_value("keytype", x)
+  info <- get_value("info", x)
   
   gson(gsid2gene = gsid2gene, gsid2name = gsid2name,
        gene2name = gene2name, species = x$species,
-       gsname = as.character(x$gsname), version = as.character(x$version),
-       accessed_date = as.character(x$accessed_date), 
-       keytype = as.character(x$keytype),
-       info = as.character(x$info))
+       gsname = gsname, version = version,
+       accessed_date = accessed_date, 
+       keytype = keytype,
+       info = info)
 }
 
 ##' @rdname IO
